Coverage for src/castep_linter/tests/castep_identifiers.py: 100%

1"""Commonly used identifiers in CASTEP"""

2

3 from castep_linter.fortran.identifier import Identifier

4

5# TRACE THINGS

6 TRACE_ENTRY = Identifier("trace_entry")

7 TRACE_EXIT = Identifier("trace_exit")

8 TRACE_STRING = Identifier("string")

9

10

11 CMPLX = Identifier("cmplx")

12

13# Parameters

14 DP = Identifier("dp")

15 DPREC = Identifier("dprec")

16

17 DP_ALL = {DP, DPREC}

18

19# Special keywords

20 STAT = Identifier("stat")

21 KIND = Identifier("kind")

22 ALLOCATE = Identifier("allocate")